=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2010-03-29 06:37:23 +0000
+++ bzrlib/builtins.py	2010-04-01 03:52:41 +0000
@@ -60,7 +60,11 @@
 from bzrlib.workingtree import WorkingTree
 """)
 
-from bzrlib.commands import Command, display_command
+from bzrlib.commands import (
+    Command,
+    builtin_command_registry,
+    display_command,
+    )
 from bzrlib.option import (
     ListOption,
     Option,
@@ -5975,7 +5979,16 @@
             self.outf.write('%s %s\n' % (path, location))
 
 
-from bzrlib.cmd_version_info import cmd_version_info
+def _register_lazy_builtins():
+    # register lazy builtins from other modules; called at startup and should
+    # be only called once.
+    for (name, aliases, module_name) in [
+        ('cmd_bundle_info', [], 'bzrlib.bundle.commands'),
+        ('cmd_version_info', [], 'bzrlib.cmd_version_info'),
+        ]:
+        builtin_command_registry.register_lazy(name, aliases, module_name)
+
+
 from bzrlib.conflicts import cmd_resolve, cmd_conflicts, restore
 from bzrlib.foreign import cmd_dpush
 from bzrlib.sign_my_commits import cmd_sign_my_commits

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2010-03-25 06:52:38 +0000
+++ bzrlib/commands.py	2010-04-01 03:52:41 +0000
@@ -182,10 +182,7 @@
     import bzrlib.builtins
     for cmd_class in _scan_module_for_commands(bzrlib.builtins).values():
         builtin_command_registry.register(cmd_class)
-    # lazy builtins
-    builtin_command_registry.register_lazy('cmd_bundle_info',
-        [],
-        'bzrlib.bundle.commands')
+    bzrlib.builtins._register_lazy_builtins()
 
 
 def _scan_module_for_commands(module):

=== modified file 'bzrlib/tests/test_import_tariff.py'
--- bzrlib/tests/test_import_tariff.py	2010-03-23 06:03:14 +0000
+++ bzrlib/tests/test_import_tariff.py	2010-04-01 03:52:41 +0000
@@ -91,6 +91,7 @@
         self.make_branch_and_tree('.')
         self.run_command_check_imports(['st'], [
             'bzrlib.bundle.commands',
+            'bzrlib.cmd_version_info',
             'bzrlib.remote',
             'bzrlib.smart',
             'smtplib',

